@@ -21,11 +21,26 @@ package mediathek.daten;
 
 import java.text.ParseException;
 import java.text.SimpleDateFormat;
-import java.util.*;
-import mediathek.controller.filme.FilmeLaden;
-import mediathek.controller.filme.filmeSuchen.sender.*;
-import mediathek.tool.DatumZeit;
+import java.util.Collections;
+import java.util.Date;
+import java.util.HashSet;
+import java.util.Iterator;
+import java.util.LinkedList;
+import java.util.ListIterator;
+import java.util.SimpleTimeZone;
+import java.util.TreeSet;
+import mediathek.controller.filmeLaden.FilmeLaden;
+import mediathek.controller.filmeLaden.suchen.sender.Mediathek3Sat;
+import mediathek.controller.filmeLaden.suchen.sender.MediathekArd;
+import mediathek.controller.filmeLaden.suchen.sender.MediathekMdr;
+import mediathek.controller.filmeLaden.suchen.sender.MediathekNdr;
+import mediathek.controller.filmeLaden.suchen.sender.MediathekWdr;
+import mediathek.controller.filmeLaden.suchen.sender.MediathekZdf;
+import mediathek.tool.Funktionen;
+import mediathek.tool.GermanStringSorter;
 import mediathek.tool.GuiFunktionen;
+import mediathek.tool.Konstanten;
+import mediathek.tool.Log;
 import mediathek.tool.TModelFilm;
 import org.apache.commons.lang3.StringEscapeUtils;
 
@@ -34,45 +49,31 @@ public class ListeFilme extends LinkedList<DatenFilm> {
     public static final String THEMA_LIVE = "Livestream";
     //Tags Infos Filmliste, erste Zeile der .filme-Datei
     public static final String FILMLISTE = "Filmliste";
-    public static final int FILMLISTE_MAX_ELEM = 6;
+    public static final int FILMLISTE_MAX_ELEM = 4;
     public static final String FILMLISTE_DATUM = "Filmliste-Datum";
     public static final int FILMLISTE_DATUM_NR = 0;
-    public static final String FILMLISTE_ZEIT = "Filmliste-Nur-Zeit";
-    public static final int FILMLISTE_NUR_ZEIT_NR = 1;
-    public static final String FILMLISTE_DATUM_ZEIT = "Filmliste-Nur-Datum";
-    public static final int FILMLISTE_NUR_DATUM_NR = 2;
-    public static final String FILMLISTE_ANZAHL = "Filmliste-Anzahl";
-    public static final int FILMLISTE_ANZAHL_NR = 3;
+    public static final String FILMLISTE_DATUM_GMT = "Filmliste-Datum-GMT";
+    public static final int FILMLISTE_DATUM_GMT_NR = 1;
     public static final String FILMLISTE_VERSION = "Filmliste-Version";
-    public static final int FILMLISTE_VERSION_NR = 4;
+    public static final int FILMLISTE_VERSION_NR = 2;
     public static final String FILMLISTE_PROGRAMM = "Filmliste-Programm";
-    public static final int FILMLISTE_PRGRAMM_NR = 5;
-    public static final String[] FILMLISTE_COLUMN_NAMES = {FILMLISTE_DATUM, FILMLISTE_ZEIT, FILMLISTE_DATUM_ZEIT,
-        FILMLISTE_ANZAHL, FILMLISTE_VERSION, FILMLISTE_PROGRAMM};
-    // Tags
-    public static final String FILMLISTE_INFOS = "Filmliste-Infos";
-    public static final int FILMLISTE_INFOS_MAX_ELEM = 2;
-    public static final String FILMLISTE_INFOS_SWR_NR_THEMA = "Filmliste-Infos-Swr-NrThema";
-    public static final int FILMLISTE_INFOS_SWR_NR_THEMA_NR = 0;
-    public static final String FILMLISTE_INFOS_test = "Filmliste-Infos-Test";
-    public static final int FILMLISTE_INFOS_test_NR = 1;
-    public static final String[] FILMLISTE_INFOS_COLUMN_NAMES = {FILMLISTE_INFOS_SWR_NR_THEMA, FILMLISTE_INFOS_test};
+    public static final int FILMLISTE_PRGRAMM_NR = 3;
+    public static final String[] FILMLISTE_COLUMN_NAMES = {FILMLISTE_DATUM, FILMLISTE_DATUM_GMT, FILMLISTE_VERSION, FILMLISTE_PROGRAMM};
     private int nr = 0;
-    public String[] infos;
     public String[] metaDaten;
+    private HashSet<String> hashSetModelOfField = new HashSet<String>();
+    private LinkedList<String> listGetModelOfField = new LinkedList<String>();
+    //private TreeSet<String> ts = new TreeSet<String>();
+    private TreeSet<String> ts = new TreeSet<String>(GermanStringSorter.getInstance());
+    private final String DATUM_ZEIT_FORMAT = "dd.MM.yyyy, HH:mm";
 
-    /**
-     *
-     * @param ddaten
-     */
     public ListeFilme() {
-        infos = newInfo();
         metaDaten = newMetaDaten();
     }
+
     //===================================
     // public
     //===================================
-
     public static String[] newMetaDaten() {
         String[] ret = new String[FILMLISTE_MAX_ELEM];
         for (int i = 0; i < ret.length; ++i) {
@@ -81,14 +82,6 @@ public class ListeFilme extends LinkedList<DatenFilm> {
         return ret;
     }
 
-    public static String[] newInfo() {
-        String[] ret = new String[FILMLISTE_INFOS_MAX_ELEM];
-        for (int i = 0; i < ret.length; ++i) {
-            ret[i] = "";
-        }
-        return ret;
-    }
-
     @Override
     public synchronized void clear() {
         nr = 0;
@@ -105,16 +98,6 @@ public class ListeFilme extends LinkedList<DatenFilm> {
         }
     }
 
-    public synchronized void setInfo(int feld, String wert) {
-        infos[feld] = wert;
-    }
-
-    public synchronized void setInfo(String[] iinfo) {
-        for (int i = 0; i < FILMLISTE_INFOS_MAX_ELEM; ++i) {
-            infos[i] = iinfo[i].toString();
-        }
-    }
-
     public synchronized void setMeta(String[] mmeta) {
         for (int i = 0; i < FILMLISTE_MAX_ELEM; ++i) {
             metaDaten[i] = mmeta[i].toString();
@@ -125,8 +108,12 @@ public class ListeFilme extends LinkedList<DatenFilm> {
         // Filme die beim Sender gesucht wurden (und nur die) hier eintragen
         // nur für die MediathekReader
         // ist eine URL,Sender,Thema,Titel schon vorhanden, wird sie verworfen, die aktuellste bleibt erhalten
-        DatenFilm f = null;
+        DatenFilm f;
+        // Thema
+        film.arr[DatenFilm.FILM_THEMA_NR] = StringEscapeUtils.unescapeXml(film.arr[DatenFilm.FILM_THEMA_NR].trim());
         film.arr[DatenFilm.FILM_THEMA_NR] = StringEscapeUtils.unescapeHtml4(film.arr[DatenFilm.FILM_THEMA_NR].trim());
+        // Titel
+        film.arr[DatenFilm.FILM_TITEL_NR] = StringEscapeUtils.unescapeXml(film.arr[DatenFilm.FILM_TITEL_NR].trim());
         film.arr[DatenFilm.FILM_TITEL_NR] = StringEscapeUtils.unescapeHtml4(film.arr[DatenFilm.FILM_TITEL_NR].trim());
         // erst mal schauen obs das schon gibt
         Iterator<DatenFilm> it = this.iterator();
@@ -142,8 +129,8 @@ public class ListeFilme extends LinkedList<DatenFilm> {
     public synchronized void updateListe(ListeFilme liste, boolean index /* Vergleich über Index, sonst nur URL */) {
         // in eine vorhandene Liste soll eine andere Filmliste einsortiert werden
         // es werden nur Filme die noch nicht vorhanden sind, einsortiert
-        DatenFilm f;
-        HashSet hashSet = new HashSet<String>();
+        DatenFilm film;
+        HashSet<String> hashSet = new HashSet<String>();
         Iterator<DatenFilm> it = this.iterator();
         while (it.hasNext()) {
             if (index) {
@@ -154,58 +141,30 @@ public class ListeFilme extends LinkedList<DatenFilm> {
         }
         it = liste.iterator();
         while (it.hasNext()) {
-            f = it.next();
+            film = it.next();
             if (index) {
-                if (!hashSet.contains(f.getIndex())) {
-                    add(f);
+                if (!hashSet.contains(film.getIndex())) {
+                    add(film);
                 }
             } else {
-                if (!hashSet.contains(f.arr[DatenFilm.FILM_URL_NR])) {
-                    add(f);
+                if (!hashSet.contains(film.arr[DatenFilm.FILM_URL_NR])) {
+                    add(film);
                 }
             }
         }
     }
 
-    public synchronized void alteThemenLöschen(String sender, LinkedList<String[]> liste) {
-        //alle Themen des Senders die NICHT in der Liste liste sind, löschen, die gibts nicht mehr
-        Iterator<DatenFilm> itIch = this.iterator();
-        Iterator<String[]> itListe;
-        DatenFilm film;
-        boolean found;
-        while (itIch.hasNext()) {
-            // ganze Liste durchlaufen
-            film = itIch.next();
-            if (film.arr[DatenFilm.FILM_SENDER_NR].equalsIgnoreCase(sender)) {
-                found = false;
-                itListe = liste.iterator();
-                while (itListe.hasNext()) {
-                    // und schauen, obs das Thema noch gibt
-                    if (film.arr[DatenFilm.FILM_THEMA_NR].equals(itListe.next()[1])) {
-                        //gibts noch
-                        found = true;
-                        break;
-                    }
-                } //while (itListe.hasNext()) {
-                if (!found) {
-                    itIch.remove();
-                }
-            }
-        } //while (itIch.hasNext()) {
-    }
-
     public synchronized boolean addWithNr(DatenFilm film) {
-        film.arr[DatenFilm.FILM_THEMA_NR] = StringEscapeUtils.unescapeHtml4(film.arr[DatenFilm.FILM_THEMA_NR].trim());
-        film.arr[DatenFilm.FILM_TITEL_NR] = StringEscapeUtils.unescapeHtml4(film.arr[DatenFilm.FILM_TITEL_NR].trim());
         film.arr[DatenFilm.FILM_NR_NR] = getNr(nr++);
         film.arr[DatenFilm.FILM_URL_NR] = film.getUrlOrg();
+        film.setDatum();
         return add(film);
     }
 
     private String getNr(int nr) {
         final int MAX_STELLEN = 5;
         final String FUELL_ZEICHEN = "0";
-        String str = String.valueOf(nr++);
+        String str = String.valueOf(nr);
         while (str.length() < MAX_STELLEN) {
             str = FUELL_ZEICHEN + str;
         }
@@ -222,14 +181,14 @@ public class ListeFilme extends LinkedList<DatenFilm> {
         }
         return ret;
     }
-//
 
-    public synchronized void delOhneSender(String sender) {
+    public synchronized void delSender(String sender) {
+        // alle Filme VOM SENDER löschen
         DatenFilm film;
         ListIterator<DatenFilm> it = this.listIterator(0);
         while (it.hasNext()) {
             film = it.next();
-            if (!film.arr[DatenFilm.FILM_SENDER_NR].equalsIgnoreCase(sender)) {
+            if (film.arr[DatenFilm.FILM_SENDER_NR].equalsIgnoreCase(sender)) {
                 it.remove();
             }
         }
@@ -257,42 +216,16 @@ public class ListeFilme extends LinkedList<DatenFilm> {
         addFilmVomSender(
                 new DatenFilm(MediathekArd.SENDER, THEMA_LIVE, ""/* urlThema */, MediathekArd.SENDER + " Phoenix" + " " + THEMA_LIVE, "http://hstreaming.zdf.de/encoder/phoenix_vh.mov", ""/* datum */, ""/* zeit */));
     }
-//
-//    /**
-//     * 
-//     * @param url
-//     * @return
-//     */
-//    public synchronized DatenFilm getFilmByUrl(String url) {
-//        DatenFilm ret = null;
-//        ListIterator<DatenFilm> it = this.listIterator(0);
-//        while (it.hasNext()) {
-//            DatenFilm f = it.next();
-//            if (f.arr[Konstanten.FILM_URL_NR].equals(url)) {
-//                ret = f;
-//                break;
-//            }
-//        }
-//        return ret;
-//    }
 
-    /**
-     *
-     * @param filterSender
-     * @param filterThema
-     * @param filterExakt
-     * @param filterText
-     * @return
-     * // */
-    public synchronized void getModelTabFilme(DDaten ddaten, TModelFilm modelFilm, String filterSender, String filterThema, String filterTitel, String filterThemaTitel) {
+    public synchronized void getModelTabFilme___(DDaten ddaten, TModelFilm modelFilm, String filterSender, String filterThema, String filterTitel, String filterThemaTitel) {
         modelFilm.setRowCount(0);
         if (this.size() != 0) {
-            ListeFilme liste = new ListeFilme();
-            Iterator<DatenFilm> it = this.iterator();
-            DatenFilm film;
             if (filterSender.equals("") && filterThema.equals("") && filterTitel.equals("") && filterThemaTitel.equals("")) {
                 addObjectDataTabFilme(ddaten, modelFilm);
             } else {
+                ListeFilme liste = new ListeFilme();
+                DatenFilm film;
+                Iterator<DatenFilm> it = this.iterator();
                 while (it.hasNext()) {
                     film = it.next();
                     // aboPruefen(String senderSuchen, String themaSuchen, boolean themaExakt, String textSuchen,
@@ -307,11 +240,38 @@ public class ListeFilme extends LinkedList<DatenFilm> {
         }
     }
 
-    public synchronized String[] getModelOfField(int feld, String filterString, int filterFeld) {
-        /* erstellt ein StringArray mit den Daten des Feldes und filtert nach filterFeld */
-        HashSet<String> tree = new HashSet<String>();
+    public synchronized TModelFilm getModelTabFilme(DDaten ddaten, TModelFilm modelFilm__, String filterSender, String filterThema, String filterTitel, String filterThemaTitel) {
+        TModelFilm modelFilm = new TModelFilm(new Object[][]{}, DatenFilm.FILME_COLUMN_NAMES);
+//        modelFilm.setRowCount(0);
+        if (this.size() != 0) {
+            if (filterSender.equals("") && filterThema.equals("") && filterTitel.equals("") && filterThemaTitel.equals("")) {
+                addObjectDataTabFilme(ddaten, modelFilm);
+            } else {
+                ListeFilme liste = new ListeFilme();
+                DatenFilm film;
+                Iterator<DatenFilm> it = this.iterator();
+                while (it.hasNext()) {
+                    film = it.next();
+                    // aboPruefen(String senderSuchen, String themaSuchen, boolean themaExakt, String textSuchen,
+                    //                     String imSender, String imThema, String imText) {
+                    if (ListeAbo.filterAufAboPruefen(filterSender, filterThema, filterTitel, filterThemaTitel,
+                            film.arr[DatenFilm.FILM_SENDER_NR], film.arr[DatenFilm.FILM_THEMA_NR], film.arr[DatenFilm.FILM_TITEL_NR])) {
+                        liste.add(film);
+                    }
+                }
+                liste.addObjectDataTabFilme(ddaten, modelFilm);
+            }
+        }
+        return modelFilm;
+    }
+
+    public synchronized String[] getModelOfField_(int feld, String filterString, int filterFeld) {
+        // erstellt ein StringArray mit den Daten des Feldes und filtert nach filterFeld
+        // ist für die Filterfelder im GuiFilme
+        // doppelte Einträge (bei der Groß- und Klienschribung) werden entfernt
         String str;
-        tree.add("");
+        String s;
+        listGetModelOfField.add("");
         DatenFilm film;
         Iterator<DatenFilm> it = this.iterator();
         if (filterString.equals("")) {
@@ -319,8 +279,10 @@ public class ListeFilme extends LinkedList<DatenFilm> {
             while (it.hasNext()) {
                 str = it.next().arr[feld];
                 //hinzufügen
-                if (!tree.contains(str)) {
-                    tree.add(str);
+                s = str.toLowerCase();
+                if (!hashSetModelOfField.contains(s)) {
+                    hashSetModelOfField.add(s);
+                    listGetModelOfField.add(str);
                 }
             }
         } else {
@@ -330,27 +292,83 @@ public class ListeFilme extends LinkedList<DatenFilm> {
                 str = film.arr[feld];
                 if (film.arr[filterFeld].equalsIgnoreCase(filterString)) {
                     //hinzufügen
-                    if (!tree.contains(str)) {
-                        tree.add(str);
+                    s = str.toLowerCase();
+                    if (!hashSetModelOfField.contains(s)) {
+                        hashSetModelOfField.add(s);
+                        listGetModelOfField.add(str);
                     }
                 }
             }
         }
-        LinkedList<String> list = new LinkedList<String>();
-        for (String h : tree) {
-            list.add(h);
-        }
-        GuiFunktionen.listeSort(list);
+        hashSetModelOfField.clear();
+        GuiFunktionen.listeSort(listGetModelOfField);
         String[] ret = new String[0];
-        ret = list.toArray(ret);
+        ret = listGetModelOfField.toArray(ret);
+        listGetModelOfField.clear();
         return ret;
     }
 
-    /**
-     *
-     * @param url
-     * @return
-     */
+    public synchronized String[] getModelOfFieldThema(String sender) {
+        // erstellt ein StringArray mit den Daten des Feldes und filtert nach filterFeld
+        // ist für die Filterfelder im GuiFilme
+        // doppelte Einträge (bei der Groß- und Klienschribung) werden entfernt
+        String str, s;
+        ts.add("");
+        DatenFilm film;
+        Iterator<DatenFilm> it = this.iterator();
+        if (sender.equals("")) {
+            //alle Theman
+            while (it.hasNext()) {
+                str = it.next().arr[DatenFilm.FILM_THEMA_NR];
+                //hinzufügen
+                s = str.toLowerCase();
+                if (!hashSetModelOfField.contains(s)) {
+                    hashSetModelOfField.add(s);
+                    ts.add(str);
+                }
+            }
+        } else {
+            //nur Theman des Senders
+            while (it.hasNext()) {
+                film = it.next();
+                if (film.arr[DatenFilm.FILM_SENDER_NR].equals(sender)) { // Filterstring ist immer "Sender"
+                    //hinzufügen
+                    str = film.arr[DatenFilm.FILM_THEMA_NR];
+                    s = str.toLowerCase();
+                    if (!hashSetModelOfField.contains(s)) {
+                        hashSetModelOfField.add(s);
+                        ts.add(str);
+                    }
+                }
+            }
+        }
+        hashSetModelOfField.clear();
+        String[] a = ts.toArray(new String[]{});
+        ts.clear();
+        return a;
+    }
+
+    public synchronized String[] getModelOfFieldSender() {
+        // erstellt ein StringArray mit den Sendernamen
+        String str;
+        ts.add("");
+        Iterator<DatenFilm> it = this.iterator();
+        // Sendernamen gibts nur in einer Schreibweise
+        int max = DDaten.filmeLaden.getSenderNamen().length; // gibt nur so viele
+        while (it.hasNext()) {
+            str = it.next().arr[DatenFilm.FILM_SENDER_NR];
+            if (!ts.contains(str)) {
+                ts.add(str);
+                if (ts.size() > max) { // eins mehr wegen Leerzeile
+                    break;
+                }
+            }
+        }
+        String[] a = ts.toArray(new String[]{});
+        ts.clear();
+        return a;
+    }
+
     public synchronized DatenFilm getFilmByUrl(String url) {
         DatenFilm ret = null;
         ListIterator<DatenFilm> it = this.listIterator(0);
@@ -364,65 +382,31 @@ public class ListeFilme extends LinkedList<DatenFilm> {
         return ret;
     }
 
-//    public static boolean filterPruefen__(String senderSuchen, String themaSuchen, String textSuchen,
-//            String imSender, String imThema, String imText) {
-//        // prüfen ob xxxSuchen im String imXxx enthalten ist, textSuchen wird mit Thema u. Titel verglichen
-//        // themaSuchen exakt mit thema
-//        Pattern p1 = makePattern(themaSuchen);
-//        boolean ret = false;
-//        if (senderSuchen.equals("") || imSender.equalsIgnoreCase(senderSuchen)) {
-//            if (p1 != null) {
-//                if (p1.matcher(imThema).matches()) {
-//                    ret = textPruefen(textSuchen, imText) || textPruefen(textSuchen, imThema);
-//                }
-//            } else if (themaSuchen.equals("")
-//                    || imThema.equalsIgnoreCase(themaSuchen)) {
-//                ret = textPruefen(textSuchen, imText) || textPruefen(textSuchen, imThema);
-//            }
-//        }
-//        return ret;
-//    }
-//    public static boolean filterPruefen_old(String senderSuchen, String themaSuchen, boolean themaExakt, String textSuchen,
-//            String imSender, String imThema, String imText) {
-//        //prüfen ob xxxSuchen im String imXxx enthalten ist
-//        Pattern p1 = makePattern(themaSuchen);
-//        boolean ret = false;
-//        if (senderSuchen.equals("") || imSender.equalsIgnoreCase(senderSuchen)) {
-//            if (p1 != null) {
-//                if (p1.matcher(imThema).matches()) {
-//                    ret = textPruefen(textSuchen, imText);
-//                }
-//            } else if (themaSuchen.equals("")
-//                    || themaExakt && imThema.equalsIgnoreCase(themaSuchen)
-//                    || !themaExakt && (imThema.toLowerCase().contains(themaSuchen.toLowerCase()))) {
-//                ret = textPruefen(textSuchen, imText);
-//            }
-//        }
-//        return ret;
-//    }
     //===================================
     // private
     //===================================
     private void addObjectDataTabFilme(DDaten ddaten, TModelFilm model) {
         Object[] object;
         DatenFilm film;
-        DatenAbo datenAbo;
+        //DatenAbo datenAbo;
         if (this.size() > 0) {
             ListIterator<DatenFilm> iterator = this.listIterator(0);
             while (iterator.hasNext()) {
                 film = iterator.next();
-                datenAbo = ddaten.listeAbo.getAbo(film.arr[DatenFilm.FILM_SENDER_NR],
-                        film.arr[DatenFilm.FILM_THEMA_NR],
-                        film.arr[DatenFilm.FILM_TITEL_NR]);
-                if (datenAbo != null) {
-                    film.arr[DatenFilm.FILM_ABO_NAME_NR] = datenAbo.arr[DatenAbo.ABO_NAME_NR];
-                } else {
-                    film.arr[DatenFilm.FILM_ABO_NAME_NR] = "";
-                }
+                // wird beim Laden der Liste gleich eintragen
+                // datenAbo = ddaten.listeAbo.getAbo(film.arr[DatenFilm.FILM_SENDER_NR],
+                //        film.arr[DatenFilm.FILM_THEMA_NR],
+                //        film.arr[DatenFilm.FILM_TITEL_NR]);
+                // if (datenAbo != null) {
+                //    film.arr[DatenFilm.FILM_ABO_NAME_NR] = datenAbo.arr[DatenAbo.ABO_NAME_NR];
+                // } else {
+                //    film.arr[DatenFilm.FILM_ABO_NAME_NR] = "";
+                // }
                 object = new Object[DatenFilm.FILME_MAX_ELEM];
                 for (int m = 0; m < DatenFilm.FILME_MAX_ELEM; ++m) {
                     if (m == DatenFilm.FILM_DATUM_NR) {
-                        object[m] = DatumZeit.getDatumForObject(film);
+                        //object[m] = DatumZeit.getDatumForObject(film);
+                        object[m] = film.datumFilm;
                     } else {
                         object[m] = film.arr[m];
                     }
@@ -432,30 +416,61 @@ public class ListeFilme extends LinkedList<DatenFilm> {
         }
     }
 
-    public int alterFilmlisteSek() {
-        // Alter der Filmliste in Sekunden
-        int ret = 0;
-        Date jetzt = new Date(System.currentTimeMillis());
-        SimpleDateFormat sdf = new SimpleDateFormat("dd.MM.yyyy, HH:mm");
-        String date = metaDaten[ListeFilme.FILMLISTE_DATUM_NR];
-        Date filmDate = null;
-        try {
-            filmDate = sdf.parse(date);
-        } catch (ParseException ex) {
+    public void abosEintragen(DDaten ddaten) {
+        DatenFilm film;
+        DatenAbo datenAbo;
+        ListIterator<DatenFilm> iterator = this.listIterator(0);
+        while (iterator.hasNext()) {
+            film = iterator.next();
+            datenAbo = ddaten.listeAbo.getAbo(film.arr[DatenFilm.FILM_SENDER_NR],
+                    film.arr[DatenFilm.FILM_THEMA_NR],
+                    film.arr[DatenFilm.FILM_TITEL_NR]);
+            if (datenAbo != null) {
+                film.arr[DatenFilm.FILM_ABO_NAME_NR] = datenAbo.arr[DatenAbo.ABO_NAME_NR];
+            } else {
+                film.arr[DatenFilm.FILM_ABO_NAME_NR] = "";
+            }
         }
-        if (jetzt != null && filmDate != null) {
-            ret = Math.round((jetzt.getTime() - filmDate.getTime()) / (1000));
-            ret = Math.abs(ret);
+    }
+
+    public String erstellt() {
+        // Tag, Zeit in lokaler Zeit wann die Filmliste erstellt wurde
+        String ret;
+        SimpleDateFormat sdf = new SimpleDateFormat(DATUM_ZEIT_FORMAT);
+        String date;
+        if (metaDaten[ListeFilme.FILMLISTE_DATUM_GMT_NR].equals("")) {
+            // noch eine alte Filmliste
+            ret = metaDaten[ListeFilme.FILMLISTE_DATUM_NR];
+        } else {
+            date = metaDaten[ListeFilme.FILMLISTE_DATUM_GMT_NR];
+            sdf.setTimeZone(new SimpleTimeZone(SimpleTimeZone.UTC_TIME, "UTC"));
+            Date filmDate = null;
+            try {
+                filmDate = sdf.parse(date);
+            } catch (ParseException ex) {
+            }
+            if (filmDate == null) {
+                ret = metaDaten[ListeFilme.FILMLISTE_DATUM_GMT_NR];
+            } else {
+                SimpleDateFormat formatter = new SimpleDateFormat(DATUM_ZEIT_FORMAT);
+                ret = formatter.format(filmDate);
+            }
         }
         return ret;
     }
 
-    public boolean filmlisteIstAelter() {
-        // Filmliste ist älter als: FilmeLaden.ALTER_FILMLISTE_SEKUNDEN_FUER_AUTOUPDATE
-        int ret = -1;
+    public int alterFilmlisteSek() {
+        // Alter der Filmliste in Sekunden
+        int ret = 0;
         Date jetzt = new Date(System.currentTimeMillis());
-        SimpleDateFormat sdf = new SimpleDateFormat("dd.MM.yyyy, HH:mm");
-        String date = metaDaten[ListeFilme.FILMLISTE_DATUM_NR];
+        SimpleDateFormat sdf = new SimpleDateFormat(DATUM_ZEIT_FORMAT);
+        String date;
+        if (!metaDaten[ListeFilme.FILMLISTE_DATUM_GMT_NR].equals("")) {
+            date = metaDaten[ListeFilme.FILMLISTE_DATUM_GMT_NR];
+            sdf.setTimeZone(new SimpleTimeZone(SimpleTimeZone.UTC_TIME, "UTC"));
+        } else {
+            date = metaDaten[ListeFilme.FILMLISTE_DATUM_NR];
+        }
         Date filmDate = null;
         try {
             filmDate = sdf.parse(date);
@@ -463,13 +478,64 @@ public class ListeFilme extends LinkedList<DatenFilm> {
         }
         if (jetzt != null && filmDate != null) {
             ret = Math.round((jetzt.getTime() - filmDate.getTime()) / (1000));
-            ret = Math.abs(ret);
+            if (ret < 0) {
+                ret = 0;
+            }
         }
-        if (ret > FilmeLaden.ALTER_FILMLISTE_SEKUNDEN_FUER_AUTOUPDATE) {
-            return true;
-        } else if (ret == -1) {
+        return ret;
+    }
+
+    public boolean filmlisteZuAlt() {
+        if (this.size() == 0) {
             return true;
         }
-        return false;
+        // Filmliste ist älter als: FilmeLaden.ALTER_FILMLISTE_SEKUNDEN_FUER_AUTOUPDATE
+        return filmlisteIstAelter(FilmeLaden.ALTER_FILMLISTE_SEKUNDEN_FUER_AUTOUPDATE);
+    }
+
+    public boolean filmlisteIstAelter(int sekunden) {
+        int ret = alterFilmlisteSek();
+//        Date jetzt = new Date(System.currentTimeMillis());
+//        SimpleDateFormat sdf = new SimpleDateFormat(DATUM_ZEIT_FORMAT);
+//        String date = metaDaten[ListeFilme.FILMLISTE_DATUM_NR];
+//        Date filmDate = null;
+//        try {
+//            filmDate = sdf.parse(date);
+//        } catch (ParseException ex) {
+//        }
+//        if (jetzt != null && filmDate != null) {
+//            ret = Math.round((jetzt.getTime() - filmDate.getTime()) / (1000));
+//            ret = Math.abs(ret);
+//        }
+        if (ret != 0) {
+            Log.systemMeldung("Die Filmliste ist " + ret / 60 + " Minuten alt");
+        }
+        return ret > sekunden;
+    }
+
+    public void metaDatenSchreiben(boolean stop) {
+        // FilmlisteMetaDaten
+        metaDaten = ListeFilme.newMetaDaten();
+        if (!Daten.filmeLaden.getStop() /* löschen */) {
+            metaDaten[ListeFilme.FILMLISTE_DATUM_NR] = getJetzt_ddMMyyyy_HHmm();
+            metaDaten[ListeFilme.FILMLISTE_DATUM_GMT_NR] = getJetzt_ddMMyyyy_HHmm_gmt();
+        } else {
+            metaDaten[ListeFilme.FILMLISTE_DATUM_NR] = "";
+            metaDaten[ListeFilme.FILMLISTE_DATUM_GMT_NR] = "";
+        }
+        //listeFilmeNeu.metaDaten[ListeFilme.FILMLISTE_ANZAHL_NR] = String.valueOf(listeFilmeNeu.size());
+        metaDaten[ListeFilme.FILMLISTE_VERSION_NR] = Konstanten.VERSION;
+        metaDaten[ListeFilme.FILMLISTE_PRGRAMM_NR] = Funktionen.getProgVersionString() + " - Compiled: " + Funktionen.getCompileDate();
+    }
+
+    private String getJetzt_ddMMyyyy_HHmm() {
+        SimpleDateFormat formatter = new SimpleDateFormat(DATUM_ZEIT_FORMAT);
+        return formatter.format(new Date());
+    }
+
+    private String getJetzt_ddMMyyyy_HHmm_gmt() {
+        SimpleDateFormat formatter = new SimpleDateFormat(DATUM_ZEIT_FORMAT);
+        formatter.setTimeZone(new SimpleTimeZone(SimpleTimeZone.UTC_TIME, "UTC"));
+        return formatter.format(new Date());
     }
 }
