@@ -22,66 +22,86 @@ package mediathek.gui.dialogEinstellungen;
 import java.awt.Cursor;
 import java.awt.event.ActionEvent;
 import java.awt.event.ActionListener;
+import java.awt.event.MouseEvent;
+import java.awt.event.MouseListener;
 import java.io.File;
+import javax.swing.JDialog;
 import javax.swing.JFileChooser;
 import javax.swing.event.DocumentEvent;
 import javax.swing.event.DocumentListener;
 import javax.swing.event.ListSelectionEvent;
-import javax.swing.event.ListSelectionListener;
-import mediathek.Daten;
-import mediathek.Konstanten;
-import mediathek.Log;
-import mediathek.controller.filme.filmeImportieren.MediathekListener;
-import mediathek.controller.filme.filmUpdateServer.DatenFilmUpdateServer;
-import mediathek.controller.filme.filmUpdateServer.FilmUpdateServer;
+import mediathek.controller.filmeLaden.importieren.DatenUrlFilmliste;
+import mediathek.controller.filmeLaden.importieren.FilmlistenSuchen;
 import mediathek.daten.DDaten;
+import mediathek.daten.Daten;
 import mediathek.gui.PanelVorlage;
 import mediathek.tool.GuiFunktionen;
 import mediathek.tool.GuiKonstanten;
+import mediathek.tool.Konstanten;
+import mediathek.tool.ListenerMediathekView;
+import mediathek.tool.Log;
 import mediathek.tool.TModel;
 
 public class PanelFilmlisteLaden extends PanelVorlage {
 
+    private JDialog dialog = null;
+
+    public PanelFilmlisteLaden(DDaten d, JDialog ddialog) {
+        super(d);
+        dialog = ddialog;
+        initComponents();
+        init();
+    }
+
     public PanelFilmlisteLaden(DDaten d) {
         super(d);
         initComponents();
         init();
+    }
+
+    private void init() {
+        initRadio();
+        tabelleLaden();
         jButtonUpdate.addActionListener(new BeobSuchen());
         jButtonDateiAuswaehlen.addActionListener(new BeobPfad());
         jButtonFilmeLaden.addActionListener(new ActionListener() {
-
             @Override
             public void actionPerformed(ActionEvent e) {
-                Daten.filmeLaden.filmeLaden(ddaten);
+                Daten.filmeLaden.importFilmliste(Daten.system[Konstanten.SYSTEM_IMPORT_URL_MANUELL_NR]);
             }
         });
         jRadioButtonUpdateAus.addActionListener(new BeobOption());
         jRadioButtonAuto.addActionListener(new BeobOption());
-        jTable1.getSelectionModel().addListSelectionListener(new BeobachterTableSelect());
+        //jTable1.getSelectionModel().addListSelectionListener(new BeobachterTableSelect());
+        jTable1.addMouseListener(new BeobachterTableSelect());
         jTextFieldUrl.getDocument().addDocumentListener(new BeobDateiUrl());
-        Daten.addAdListener(new MediathekListener(MediathekListener.EREIGNIS_LISTE_UPDATESERVER, PanelFilmlisteLaden.class.getSimpleName()) {
-
+        ListenerMediathekView.addListener(new ListenerMediathekView(ListenerMediathekView.EREIGNIS_LISTE_URL_FILMLISTEN, PanelFilmlisteLaden.class.getSimpleName()) {
             @Override
             public void ping() {
                 tabelleLaden();
             }
         });
+        ListenerMediathekView.addListener(new ListenerMediathekView(ListenerMediathekView.EREIGNIS_ART_IMPORT_FILMLISTE, PanelFilmlisteLaden.class.getSimpleName()) {
+            @Override
+            public void ping() {
+                initRadio();
+            }
+        });
     }
 
-    private void init() {
+    private void initRadio() {
         if (GuiFunktionen.getImportArtFilme() == GuiKonstanten.UPDATE_FILME_AUS) {
             jRadioButtonUpdateAus.setSelected(true);
         } else {
             jRadioButtonAuto.setSelected(true);
         }
         jTextFieldUrl.setText(Daten.system[Konstanten.SYSTEM_IMPORT_URL_MANUELL_NR]);
-        tabelleLaden();
         setPanelTabelle(jRadioButtonUpdateAus.isSelected());
     }
 
     private void updateSuchen() {
         this.setCursor(Cursor.getPredefinedCursor(Cursor.WAIT_CURSOR));
-        DDaten.filmeLaden.getListeFilmUpdateServer(true); // Liste neu laden und eine URL auswählen
+        DDaten.filmeLaden.getDownloadUrlsFilmlisten(true); // Liste neu laden und eine URL auswählen
         stopBeob = true;
         jTextFieldUrl.setText(Daten.system[Konstanten.SYSTEM_IMPORT_URL_MANUELL_NR]);
         tabelleLaden();
@@ -90,14 +110,14 @@ public class PanelFilmlisteLaden extends PanelVorlage {
     }
 
     private void tabelleLaden() {
-        TModel model = new TModel(DDaten.filmeLaden.getListeFilmUpdateServer(false).getTableObjectData(), FilmUpdateServer.FILM_UPDATE_SERVER_COLUMN_NAMES_ANZEIGE);
+        TModel model = new TModel(DDaten.filmeLaden.getDownloadUrlsFilmlisten(false).getTableObjectData(), FilmlistenSuchen.FILM_UPDATE_SERVER_COLUMN_NAMES_ANZEIGE);
         jTable1.setModel(model);
         for (int i = 0; i < jTable1.getColumnCount(); ++i) {
-            if (i == FilmUpdateServer.FILM_UPDATE_SERVER_URL_NR) {
+            if (i == FilmlistenSuchen.FILM_UPDATE_SERVER_URL_NR) {
                 jTable1.getColumnModel().getColumn(i).setMinWidth(10);
                 jTable1.getColumnModel().getColumn(i).setMaxWidth(3000);
                 jTable1.getColumnModel().getColumn(i).setPreferredWidth(350);
-            } else if (i == FilmUpdateServer.FILM_UPDATE_SERVER_PRIO_NR || i == FilmUpdateServer.FILM_UPDATE_SERVER_ANZAHL_NR) {
+            } else if (!Daten.debug && i == FilmlistenSuchen.FILM_UPDATE_SERVER_PRIO_NR) {
                 jTable1.getColumnModel().getColumn(i).setMinWidth(0);
                 jTable1.getColumnModel().getColumn(i).setMaxWidth(0);
                 jTable1.getColumnModel().getColumn(i).setPreferredWidth(0);
@@ -109,21 +129,28 @@ public class PanelFilmlisteLaden extends PanelVorlage {
         }
     }
 
-    private void table1Select() {
+    private void table1Select(boolean doppel) {
         stopBeob = true;
-        DatenFilmUpdateServer aktUpdate = null;
+        DatenUrlFilmliste datenUrlFilmliste = null;
         int selectedTableRow = jTable1.getSelectedRow();
         if (selectedTableRow >= 0) {
-            aktUpdate = Daten.filmeLaden.getListeFilmUpdateServer(false).getNrUpdate(jTable1.getModel().getValueAt(jTable1.convertRowIndexToModel(selectedTableRow),
-                    FilmUpdateServer.FILM_UPDATE_SERVER_URL_NR).toString());
+            datenUrlFilmliste = Daten.filmeLaden.getDownloadUrlsFilmlisten(false).getDatenUrlFilmliste(jTable1.getModel().getValueAt(jTable1.convertRowIndexToModel(selectedTableRow),
+                    FilmlistenSuchen.FILM_UPDATE_SERVER_URL_NR).toString());
         }
-        if (aktUpdate != null) {
+        if (datenUrlFilmliste != null) {
             //jRadioButtonUpdateAus.setSelected(true);
             //daten.system[Konstanten.SYSTEM_IMPORT_ART_FILME_NR] = String.valueOf(Konstanten.UPDATE_FILME_AUS);
-            jTextFieldUrl.setText(aktUpdate.arr[FilmUpdateServer.FILM_UPDATE_SERVER_URL_NR]);
-            Daten.system[Konstanten.SYSTEM_IMPORT_URL_MANUELL_NR] = aktUpdate.arr[FilmUpdateServer.FILM_UPDATE_SERVER_URL_NR];
+            jTextFieldUrl.setText(datenUrlFilmliste.arr[FilmlistenSuchen.FILM_UPDATE_SERVER_URL_NR]);
+            Daten.system[Konstanten.SYSTEM_IMPORT_URL_MANUELL_NR] = datenUrlFilmliste.arr[FilmlistenSuchen.FILM_UPDATE_SERVER_URL_NR];
+            if (doppel) {
+                // dann wars ein Doppelklick, gleich laden
+                Daten.filmeLaden.importFilmliste(Daten.system[Konstanten.SYSTEM_IMPORT_URL_MANUELL_NR]);
+            }
         }
         stopBeob = false;
+        if (doppel && dialog != null) {
+            dialog.dispose();
+        }
     }
 
     private void setPanelTabelle(boolean manuell) {
@@ -335,29 +362,50 @@ public class PanelFilmlisteLaden extends PanelVorlage {
         @Override
         public void actionPerformed(ActionEvent e) {
             if (!stopBeob) {
-                setPanelTabelle(jRadioButtonUpdateAus.isSelected());
                 if (jRadioButtonUpdateAus.isSelected()) {
                     Daten.system[Konstanten.SYSTEM_IMPORT_ART_FILME_NR] = String.valueOf(GuiKonstanten.UPDATE_FILME_AUS);
                 } else {
                     Daten.system[Konstanten.SYSTEM_IMPORT_ART_FILME_NR] = String.valueOf(GuiKonstanten.UPDATE_FILME_AUTO);
-                }
-                Daten.setGeaendert();
+                }                // den Dialog gibts 2x
+                ListenerMediathekView.notify(ListenerMediathekView.EREIGNIS_ART_IMPORT_FILMLISTE, this.getClass().getSimpleName());
             }
         }
     }
 
-    private class BeobachterTableSelect implements ListSelectionListener {
+    private class BeobachterTableSelect implements MouseListener {
 
-        public int selectedModelRow = -1;
-
-        @Override
         public void valueChanged(ListSelectionEvent event) {
             if (!stopBeob) {
                 if (!event.getValueIsAdjusting()) {
-                    table1Select();
+                    table1Select(false);
                 }
             }
         }
+
+        @Override
+        public void mouseClicked(MouseEvent e) {
+            if (e.getClickCount() == 2) {
+                table1Select(true);
+            } else {
+                table1Select(false);
+            }
+        }
+
+        @Override
+        public void mousePressed(MouseEvent e) {
+        }
+
+        @Override
+        public void mouseReleased(MouseEvent e) {
+        }
+
+        @Override
+        public void mouseEntered(MouseEvent e) {
+        }
+
+        @Override
+        public void mouseExited(MouseEvent e) {
+        }
     }
 
     private class BeobPfad implements ActionListener {
@@ -376,7 +424,7 @@ public class PanelFilmlisteLaden extends PanelVorlage {
                 try {
                     jTextFieldUrl.setText(chooser.getSelectedFile().getAbsolutePath());
                 } catch (Exception ex) {
-                    Log.fehlerMeldung("PanelImportFilme.BeobPfad", ex);
+                    Log.fehlerMeldung(733025319,Log.FEHLER_ART_PROG, "PanelImportFilme.BeobPfad", ex);
                 }
             }
         }
@@ -401,7 +449,6 @@ public class PanelFilmlisteLaden extends PanelVorlage {
 
         private void tus() {
             Daten.system[Konstanten.SYSTEM_IMPORT_URL_MANUELL_NR] = jTextFieldUrl.getText();
-            Daten.setGeaendert();
         }
     }
 }
