@@ -29,19 +29,18 @@ import javax.swing.JPanel;
 import javax.swing.JTextField;
 import javax.swing.event.DocumentEvent;
 import javax.swing.event.DocumentListener;
-import mediathek.Daten;
-import mediathek.Konstanten;
-import mediathek.Log;
+import mediathek.daten.Daten;
 import mediathek.file.GetFile;
-import mediathek.gui.beobachter.BeobWeb;
 import mediathek.gui.dialog.DialogHilfe;
+import mediathek.tool.BeobWeb;
 import mediathek.tool.GuiFunktionen;
 import mediathek.tool.GuiFunktionenProgramme;
+import mediathek.tool.Konstanten;
+import mediathek.tool.Log;
 
 public class PanelProgrammPfade extends JPanel {
 
     public JDialog dialog = null;
-    private boolean helpModal = false;
     private boolean vlc, flvstreamer, mplayer;
 
     public PanelProgrammPfade(boolean vvlc, boolean fflvstreamer, boolean mmplayer) {
@@ -112,7 +111,7 @@ public class PanelProgrammPfade extends JPanel {
 
             @Override
             public void actionPerformed(ActionEvent e) {
-                new DialogHilfe(null, helpModal, new GetFile().getHilfeSuchen(GetFile.PFAD_HILFETEXT_STANDARD_PSET)).setVisible(true);
+                new DialogHilfe(null, true, new GetFile().getHilfeSuchen(GetFile.PFAD_HILFETEXT_STANDARD_PSET)).setVisible(true);
             }
         });
     }
@@ -465,7 +464,7 @@ public class PanelProgrammPfade extends JPanel {
                 try {
                     textField.setText(chooser.getSelectedFile().getAbsolutePath());
                 } catch (Exception ex) {
-                    Log.fehlerMeldung("PanelImportStandardProgramme.BeobPfad", ex);
+                    Log.fehlerMeldung(643289561,Log.FEHLER_ART_PROG,"PanelImportStandardProgramme.BeobPfad", ex);
                 }
             }
         }
