@@ -26,18 +26,24 @@ import java.awt.Insets;
 import java.awt.event.ActionEvent;
 import java.awt.event.ActionListener;
 import java.io.File;
-import javax.swing.*;
+import javax.swing.DefaultComboBoxModel;
+import javax.swing.JButton;
+import javax.swing.JFileChooser;
+import javax.swing.JLabel;
+import javax.swing.JOptionPane;
+import javax.swing.JPanel;
+import javax.swing.JTextField;
 import javax.swing.event.DocumentEvent;
 import javax.swing.event.DocumentListener;
 import javax.swing.event.ListSelectionEvent;
 import javax.swing.event.ListSelectionListener;
-import mediathek.Log;
 import mediathek.daten.DDaten;
 import mediathek.daten.DatenProg;
 import mediathek.daten.DatenPset;
 import mediathek.daten.ListePset;
 import mediathek.gui.PanelVorlage;
 import mediathek.tool.GuiFunktionen;
+import mediathek.tool.Log;
 
 public class PanelPsetKurz extends PanelVorlage {
 
@@ -75,19 +81,6 @@ public class PanelPsetKurz extends PanelVorlage {
         jTextFieldName.getDocument().addDocumentListener(new BeobDocName());
         jTextFieldZiel.getDocument().addDocumentListener(new BeobDoc(jTextFieldZiel, DatenPset.PROGRAMMSET_ZIEL_PFAD_NR));
         jButtonZiel.addActionListener(new ZielBeobachter(false, jTextFieldZiel, DatenPset.PROGRAMMSET_ZIEL_PFAD_NR));
-        jCheckBoxFragen.addActionListener(new ActionListener() {
-
-            @Override
-            public void actionPerformed(ActionEvent e) {
-                jTextFieldZiel.setEnabled(!jCheckBoxFragen.isSelected());
-                jButtonZiel.setEnabled(!jCheckBoxFragen.isSelected());
-                if (jCheckBoxFragen.isSelected()) {
-                    jTextFieldZiel.setText("%p");
-                } else {
-                    jTextFieldZiel.setText(GuiFunktionen.getHomePath());
-                }
-            }
-        });
     }
 
     private void init() {
@@ -96,14 +89,9 @@ public class PanelPsetKurz extends PanelVorlage {
         if (!pSet.istSpeichern() && pSet.arr[DatenPset.PROGRAMMSET_ZIEL_PFAD_NR].equals("")) {
             jTextFieldZiel.setEditable(false);
             jButtonZiel.setEnabled(false);
-            jCheckBoxFragen.setEnabled(false);
         } else {
             jTextFieldZiel.setEditable(true);
             jButtonZiel.setEnabled(true);
-            jCheckBoxFragen.setEnabled(true);
-            jCheckBoxFragen.setSelected(pSet.arr[DatenPset.PROGRAMMSET_ZIEL_PFAD_NR].equals("%p"));
-            jTextFieldZiel.setEnabled(!jCheckBoxFragen.isSelected());
-            jButtonZiel.setEnabled(!jCheckBoxFragen.isSelected());
             // Zielpfad muss gesetzt werden
             if (pSet.arr[DatenPset.PROGRAMMSET_ZIEL_PFAD_NR].equals("")) {
                 pSet.arr[DatenPset.PROGRAMMSET_ZIEL_PFAD_NR] = GuiFunktionen.getHomePath();
@@ -216,7 +204,6 @@ public class PanelPsetKurz extends PanelVorlage {
         jButtonZiel = new javax.swing.JButton();
         jScrollPane2 = new javax.swing.JScrollPane();
         jTextArea1 = new javax.swing.JTextArea();
-        jCheckBoxFragen = new javax.swing.JCheckBox();
         jScrollPane1 = new javax.swing.JScrollPane();
         jListPset = new javax.swing.JList();
 
@@ -273,14 +260,12 @@ public class PanelPsetKurz extends PanelVorlage {
 
         jScrollPane2.setBorder(javax.swing.BorderFactory.createLineBorder(javax.swing.UIManager.getDefaults().getColor("TextField.selectionBackground")));
 
+        jTextArea1.setEditable(false);
         jTextArea1.setBackground(javax.swing.UIManager.getDefaults().getColor("TextField.inactiveBackground"));
         jTextArea1.setColumns(20);
-        jTextArea1.setEditable(false);
         jTextArea1.setRows(8);
         jScrollPane2.setViewportView(jTextArea1);
 
-        jCheckBoxFragen.setText("Bei jedem Film nach dem Pfad fragen");
-
         jListPset.setModel(new javax.swing.AbstractListModel() {
             String[] strings = { "Item 1", "Item 2", "Item 3", "Item 4" };
             public int getSize() { return strings.length; }
@@ -295,7 +280,7 @@ public class PanelPsetKurz extends PanelVorlage {
             .addGroup(jPanel1Layout.createSequentialGroup()
                 .addContainerGap()
                 .addGroup(jPanel1Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
-                    .addComponent(jScrollPane2)
+                    .addComponent(jScrollPane2, javax.swing.GroupLayout.DEFAULT_SIZE, 452, Short.MAX_VALUE)
                     .addComponent(jTextField2)
                     .addGroup(jPanel1Layout.createSequentialGroup()
                         .addGroup(jPanel1Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
@@ -303,9 +288,6 @@ public class PanelPsetKurz extends PanelVorlage {
                             .addComponent(jLabel2))
                         .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                         .addGroup(jPanel1Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
-                            .addGroup(jPanel1Layout.createSequentialGroup()
-                                .addComponent(jCheckBoxFragen)
-                                .addGap(0, 87, Short.MAX_VALUE))
                             .addGroup(jPanel1Layout.createSequentialGroup()
                                 .addComponent(jTextFieldZiel)
                                 .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
@@ -332,9 +314,7 @@ public class PanelPsetKurz extends PanelVorlage {
                         .addComponent(jLabel2)
                         .addComponent(jTextFieldZiel, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)))
                 .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.UNRELATED)
-                .addComponent(jCheckBoxFragen)
-                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
-                .addComponent(jScrollPane2, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
+                .addComponent(jScrollPane2, javax.swing.GroupLayout.PREFERRED_SIZE, 143, javax.swing.GroupLayout.PREFERRED_SIZE)
                 .addContainerGap(javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE))
         );
 
@@ -363,7 +343,6 @@ public class PanelPsetKurz extends PanelVorlage {
     }// </editor-fold>//GEN-END:initComponents
     // Variables declaration - do not modify//GEN-BEGIN:variables
     private javax.swing.JButton jButtonZiel;
-    private javax.swing.JCheckBox jCheckBoxFragen;
     private javax.swing.JLabel jLabel1;
     private javax.swing.JLabel jLabel2;
     private javax.swing.JList jListPset;
@@ -420,7 +399,7 @@ public class PanelPsetKurz extends PanelVorlage {
                         arr[idx] = textField.getText();
                     }
                 } catch (Exception ex) {
-                    Log.fehlerMeldung("DialogZielPset.ZielBeobachter", ex);
+                    Log.fehlerMeldung(613986500,Log.FEHLER_ART_PROG,"DialogZielPset.ZielBeobachter", ex);
                 }
             }
         }
