@@ -25,18 +25,14 @@ public class TModelDownload extends TModel {
 
     Class[] types;
 
-    /** Creates a new instance of TModel */
-    public TModelDownload() {
-    }
-
     public TModelDownload(Object[][] data, Object[] columnNames) {
         super(data, columnNames);
         types = new Class[DatenDownload.DOWNLOAD_MAX_ELEM];
         for (int i = 0; i < DatenDownload.DOWNLOAD_MAX_ELEM; ++i) {
-            if (i != DatenDownload.DOWNLOAD_DATUM_NR) {
-                types[i] = String.class;
-            } else {
+            if (i == DatenDownload.DOWNLOAD_DATUM_NR) {
                 types[i] = Datum.class;
+            } else {
+                types[i] = String.class;
             }
         }
     }
